@@ -16,4 +16,4 @@ from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-from .strategies import Moonshot
\ No newline at end of file
+from .strategies import Moonshot, MoonshotML
\ No newline at end of file
